Global Configuration Options — pyqtgraph 0.11.0rc0 documentation

# Global Configuration Options

PyQtGraph has several global configuration options that allow you to change its default behavior. These can be accessed using the `setConfigOptions()` and `getConfigOption()` functions:

Option | Type | Default |
leftButtonPan | bool | True | If True, dragging the left mouse button over a ViewBox causes the view to be panned. If False, then dragging the left mouse button draws a rectangle that the ViewBox will zoom to.
foreground | See `mkColor()` | ‘d’ | Default foreground color for text, lines, axes, etc.
background | See `mkColor()` | ‘k’ | Default background for `GraphicsView`.
antialias | bool | False | Enabling antialiasing causes lines to be drawn with smooth edges at the cost of reduced performance.
imageAxisOrder | str | ‘col-major’ | For ‘row-major’, image data is expected in the standard row-major (row, col) order. For ‘col-major’, image data is expected in reversed column-major (col, row) order. The default is ‘col-major’ for backward compatibility, but this may change in the future.
editorCommand | str or None | None | Command used to invoke code editor from ConsoleWidget.
exitCleanup | bool | True | Attempt to work around some exit crash bugs in PyQt and PySide.
useWeave | bool | False | Use weave to speed up some operations, if it is available.
weaveDebug | bool | False | Print full error message if weave compile fails.
useOpenGL | bool | False | Enable OpenGL in GraphicsView. This can have unpredictable effects on stability and performance.
enableExperimental | bool | False | Enable experimental features (the curious can search for this key in the code).
crashWarning | bool | False | If True, print warnings about situations that may result in a crash.

`pyqtgraph.` `setConfigOptions`(**opts)

  Set global configuration options.

  Each keyword argument sets one global option.

`pyqtgraph.` `getConfigOption`(opt)

  Return the value of a single global configuration option.